import React, { useState, useEffect, lazy, Suspense } from 'react';
import { BrowserRouter as Router, Routes, Route, Link } from 'react-router-dom';
import { 
  Linkedin, 
  Package, 
  Menu, 
  X,
  ArrowRight
} from 'lucide-react';

// Import existing pages
import Home from './pages/Home';
import Features from './pages/Features';
import About from './pages/About';
import Solutions from './pages/Solutions';
import Contact from './pages/Contact';
import Track from './pages/Track';
import Deliveries from './pages/Deliveries';
import RouteOptimization from './pages/RouteOptimization';
import DriverApp from './pages/DriverApp';
import DSPs from './pages/DSPs';
import FAQ from './pages/FAQ';
import Cities from './pages/Cities';
import PrivacyPolicy from './pages/PrivacyPolicy';
import ProofOfDelivery from './pages/ProofOfDelivery';
import Resources from './pages/Resources';
import Terms from './pages/Terms';
import NotFound from './pages/NotFound';
import Integrations from './pages/Integrations';
import RecipientNotifications from './pages/RecipientNotifications';
import Sitemap from './pages/Sitemap';
import LogisticsOS from './pages/LogisticsOS';
import Startups from './pages/Startups';
import LogisticsSoftware from './pages/LogisticsSoftware';

// Import new SEO-focused landing pages
import LastMileDeliveryManagement from './pages/landing/LastMileDeliveryManagement';
import ElectronicProofOfDelivery from './pages/landing/ElectronicProofOfDelivery';
import AIRouteOptimization from './pages/landing/AIRouteOptimization';
import LastMileDeliverySolutions from './pages/landing/LastMileDeliverySolutions';
import DeliveryTracking from './pages/landing/DeliveryTracking';
import CourierSoftware from './pages/landing/CourierSoftware';
import TransportationManagement from './pages/landing/TransportationManagement';
import DriverMobileApp from './pages/landing/DriverMobileApp';
import DeliveryManagementSoftware from './pages/landing/DeliveryManagementSoftware';
import CourierDispatchSoftware from './pages/landing/CourierDispatchSoftware';
import ProofOfDeliveryApp from './pages/landing/ProofOfDeliveryApp';

// Lazy load resource pages to improve performance
const ResourcePage = lazy(() => import('./pages/ResourcePage'));

// Import components
import SiteFooter from './components/SiteFooter';
import ScrollToTop from './components/ScrollToTop';

function App() {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

  useEffect(() => {
    const handleScroll = () => {
      setIsScrolled(window.scrollY > 10);
    };

    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  useEffect(() => {
    if (isMobileMenuOpen) {
      document.body.style.overflow = 'hidden';
    } else {
      document.body.style.overflow = 'unset';
    }
  }, [isMobileMenuOpen]);

  return (
    <Router>
      <ScrollToTop />
      <div className="min-h-screen bg-white">
        {/* Mobile Navigation Menu */}
        <div 
          className={`fixed inset-0 bg-black/50 z-50 transition-opacity duration-300 md:hidden ${
            isMobileMenuOpen ? 'opacity-100' : 'opacity-0 pointer-events-none'
          }`}
          onClick={() => setIsMobileMenuOpen(false)}
        >
          <div 
            className={`absolute right-0 top-0 h-full w-64 bg-white shadow-xl transform transition-transform duration-300 ${
              isMobileMenuOpen ? 'translate-x-0' : 'translate-x-full'
            }`}
            onClick={e => e.stopPropagation()}
          >
            <div className="p-6">
              <button 
                onClick={() => setIsMobileMenuOpen(false)}
                className="absolute top-4 right-4 p-2 hover:bg-gray-100 rounded-lg transition-colors duration-200"
              >
                <X className="w-6 h-6 text-gray-600" />
              </button>
              
              <div className="mt-16 flex flex-col space-y-6">
                <Link 
                  to="/"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Home
                </Link>
                <Link 
                  to="/solutions"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Solutions
                </Link>
                <Link 
                  to="/deliveries"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Deliveries
                </Link>
                <Link 
                  to="/features"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Features
                </Link>
                <Link 
                  to="/dsps"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  DSPs
                </Link>
                <Link 
                  to="/about"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  About
                </Link>
                <Link 
                  to="/resources"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Resources
                </Link>
                <Link 
                  to="/logistics-software"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Logistics Software
                </Link>
                <Link 
                  to="/contact"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Contact
                </Link>
              </div>

              <div className="absolute bottom-8 inset-x-6">
                <Link 
                  to="/track"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="flex items-center justify-center space-x-2 w-full bg-[#2f1c8c] text-white px-4 py-3 rounded-lg font-medium hover:bg-[#2f1c8c]/90 transition-all duration-300"
                >
                  <Package className="w-5 h-5" />
                  <span>Track Parcel</span>
                </Link>
              </div>
            </div>
          </div>
        </div>

        {/* Navigation */}
        <nav 
          className={`fixed w-full z-40 transition-all duration-300 ${
            isScrolled 
              ? 'bg-white/95 backdrop-blur-sm shadow-md py-3' 
              : 'bg-[#2f1c8c] py-4'
          }`}
        >
          <div className="container mx-auto px-4 md:px-6">
            <div className="flex items-center justify-between">
              {/* Mobile menu button */}
              <button 
                className="md:hidden p-2 hover:bg-white/10 rounded-lg transition-colors duration-200"
                onClick={() => setIsMobileMenuOpen(true)}
                aria-label="Open menu"
              >
                <Menu className={`w-6 h-6 ${isScrolled ? 'text-gray-800' : 'text-white'}`} />
              </button>

              <Link to="/" className="hover-scale">
                <svg 
                  className={`w-16 h-auto transition-all duration-300 ${
                    isScrolled ? 'fill-[#2f1c8c]' : 'fill-white'
                  }`} 
                  viewBox="0 0 179.89 139.36" 
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <g>
                    <path d="M29.15,69.73v.68h20.34v24.23H30v44.72H0V66.34c0-19.66,13.73-28.81,34.91-28.81,4.91,0,10,.51,15.59,1.36v20.67c-2.71-.51-5.93-.68-8.3-.68-8.98,0-13.05,3.39-13.05,10.85Z"/>
                    <path d="M56.31,139.36V70.2h29.44v69.16h-29.44Z"/>
                    <path d="M179.89,106.63v32.73h-29.61v-29.41c0-9.81-4.82-15.14-13.47-15.14-9.65,0-12.97,5.66-12.97,15.64v28.91h-29.44V70.2h27.11l1,9.98c6.49-7.65,13.14-11.64,23.95-11.64,22.79,0,33.43,15.14,33.43,38.09Z"/>
                    <path d="M88.73,0h0c-17.91,0-32.43,14.52-32.43,32.43v32.43h32.43c17.91,0,32.43-14.52,32.43-32.43h0C121.16,14.52,106.64,0,88.73,0Zm0,46.88c-7.98,0-14.45-6.47-14.45-14.45s6.47-14.45,14.45-14.45,14.45,6.47,14.45,14.45-6.47,14.45-14.45,14.45Z"/>
                  </g>
                </svg>
              </Link>

              {/* Desktop Navigation Links */}
              <div className="hidden md:flex items-center space-x-8">
                <Link 
                  to="/solutions" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Solutions
                </Link>
                <Link 
                  to="/deliveries" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Deliveries
                </Link>
                <Link 
                  to="/features" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Features
                </Link>
                <Link 
                  to="/dsps" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  DSPs
                </Link>
                <Link 
                  to="/about" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  About
                </Link>
                <Link 
                  to="/resources" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Resources
                </Link>
                <Link 
                  to="/logistics-software" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Logistics Software
                </Link>
              </div>

              {/* Desktop Action Buttons */}
              <div className="hidden md:flex items-center space-x-4">
                <Link 
                  to="/track"
                  className={`inline-flex items-center px-5 py-2 rounded-lg text-sm font-medium transition-all duration-300 hover:shadow-lg transform hover:scale-105 ${
                    isScrolled 
                      ? 'bg-[#2f1c8c]/10 text-[#2f1c8c] hover:bg-[#2f1c8c]/20' 
                      : 'bg-white/10 text-white hover:bg-white/20'
                  }`}
                >
                  <Package className="w-4 h-4 mr-2" />
                  Track Parcel
                </Link>
                <Link 
                  to="/contact"
                  className={`px-5 py-2 rounded-lg text-sm font-medium transition-all duration-300 hover:shadow-lg transform hover:scale-105 ${
                    isScrolled 
                      ? 'bg-[#2f1c8c] text-white hover:bg-[#2f1c8c]/90' 
                      : 'bg-white text-[#2f1c8c] hover:bg-gray-100'
                  }`}
                >
                  Request a Demo
                </Link>
              </div>
            </div>
          </div>
        </nav>

        {/* Add padding to account for fixed navbar */}
        <div className="pt-20">
          <Routes>
            {/* Main Routes */}
            <Route path="/" element={<Home />} />
            <Route path="/solutions" element={<Solutions />} />
            <Route path="/features" element={<Features />} />
            <Route path="/about" element={<About />} />
            <Route path="/contact" element={<Contact />} />
            <Route path="/track" element={<Track />} />
            <Route path="/deliveries" element={<Deliveries />} />
            <Route path="/route-optimization" element={<RouteOptimization />} />
            <Route path="/driver-app" element={<DriverApp />} />
            <Route path="/dsps" element={<DSPs />} />
            <Route path="/faq" element={<FAQ />} />
            <Route path="/cities" element={<Cities />} />
            <Route path="/privacy-policy" element={<PrivacyPolicy />} />
            <Route path="/proof-of-delivery" element={<ProofOfDelivery />} />
            <Route path="/resources" element={<Resources />} />
            <Route path="/terms" element={<Terms />} />
            <Route path="/integrations" element={<Integrations />} />
            <Route path="/recipient-notifications" element={<RecipientNotifications />} />
            <Route path="/sitemap" element={<Sitemap />} />
            <Route path="/logistics-os" element={<LogisticsOS />} />
            <Route path="/startups" element={<Startups />} />
            <Route path="/logistics-software" element={<LogisticsSoftware />} />

            {/* SEO Landing Pages */}
            <Route path="/delivery-management-software" element={<DeliveryManagementSoftware />} />
            <Route path="/proof-of-delivery-app" element={<ProofOfDeliveryApp />} />
            <Route path="/ai-route-optimization" element={<AIRouteOptimization />} />
            <Route path="/last-mile-delivery-solutions" element={<LastMileDeliverySolutions />} />
            <Route path="/delivery-tracking-software" element={<DeliveryTracking />} />
            <Route path="/courier-software" element={<CourierSoftware />} />
            <Route path="/transportation-management-system" element={<TransportationManagement />} />
            <Route path="/driver-mobile-app" element={<DriverMobileApp />} />
            <Route path="/courier-dispatch-software" element={<CourierDispatchSoftware />} />
            <Route path="/electronic-proof-of-delivery" element={<ElectronicProofOfDelivery />} />

            {/* Dynamic Resource Routes */}
            <Route 
              path="/resources/:slug" 
              element={
                <Suspense fallback={<div className="min-h-screen flex items-center justify-center">Loading...</div>}>
                  <ResourcePage />
                </Suspense>
              } 
            />

            {/* 404 Route */}
            <Route path="*" element={<NotFound />} />
          </Routes>

          {/* Footer */}
          <SiteFooter />
        </div>
      </div>
    </Router>
  );
}

export default App;